@@ -15,7 +15,6 @@ from ampform.dynamics import (
     BlattWeisskopfSquared,
     _analytic_continuation,
     breakup_momentum_squared,
-    complex_sqrt,
     coupled_width,
     phase_space_factor,
     phase_space_factor_ac,
@@ -97,17 +96,6 @@ def render_coupled_width() -> None:
     )
 
 
-def render_complex_sqrt() -> None:
-    x = sp.Symbol("x", real=True)
-    update_docstring(
-        complex_sqrt,
-        fR"""
-    .. math:: {sp.latex(complex_sqrt(x))}
-        :label: complex_sqrt
-    """,
-    )
-
-
 def render_phase_space_factor() -> None:
     s, m_a, m_b = sp.symbols("s, m_a, m_b")
     rho = phase_space_factor(s, m_a, m_b)
